# CHANGELOG

<!-- version list -->

## v1.0.1 (2025-08-14)

### Bug Fixes

- Trigger pypi upload
  ([`c6ee792`](https://github.com/bGuenes/COMPASS/commit/c6ee792e9e3b9599cfdd0f1473a561aa62894b13))


## v1.0.0 (2025-08-14)

### Bug Fixes

- Zenodo information file
  ([`bbf91bc`](https://github.com/bGuenes/COMPASS/commit/bbf91bceb01aaf1cac757e2c88d1aeb3445ad59a))

### Chores

- Enhance release workflow with semantic-release and add changelog
  ([`881c9a2`](https://github.com/bGuenes/COMPASS/commit/881c9a2061a595f9942ca0796bf3a30065a6c47b))


## v0.1.5 (2025-05-02)

- Initial Release
